@@ -16,5 +16,9 @@ sys.modules['Quartz.QuartzFilters'] = mod = objc.ObjCLazyModule('Quartz.QuartzFi
     _metadata.__dict__, None, {
        '__doc__': __doc__,
        '__path__': __path__,
+       '__loader__': globals().get('__loader__', None),
        'objc': objc,
     }, ( Foundation,))
+
+import sys
+del sys.modules['Quartz.QuartzFilters._metadata']
