@@ -4,16 +4,6 @@ from Quartz.CoreGraphics import *
 import array
 import sys
 
-try:
-    long
-except NameError:
-    long = int
-
-try:
-    unicode
-except NameError:
-    unicode = str
-
 if sys.version_info[0] != 2:
     def buffer(value):
         if isinstance(value, bytes):
@@ -36,6 +26,7 @@ class TestCGColorSpace (TestCase):
         self.assertEqual(kCGColorSpaceModelDeviceN, 4)
         self.assertEqual(kCGColorSpaceModelIndexed, 5)
         self.assertEqual(kCGColorSpaceModelPattern, 6)
+        self.assertEqual(kCGColorSpaceModelXYZ, 7)
 
         self.assertIsInstance(kCGColorSpaceGenericGray, unicode)
         self.assertIsInstance(kCGColorSpaceGenericRGB, unicode)
@@ -51,11 +42,33 @@ class TestCGColorSpace (TestCase):
         self.assertIsInstance(kCGColorSpaceAdobeRGB1998, unicode)
         self.assertIsInstance(kCGColorSpaceSRGB, unicode)
 
-
     @min_os_level('10.6')
     def testConstants10_6(self):
         self.assertIsInstance(kCGColorSpaceGenericGrayGamma2_2, unicode)
 
+    @min_os_level('10.11')
+    def testConstants10_11(self):
+        self.assertIsInstance(kCGColorSpaceDisplayP3, unicode)
+
+        self.assertIsInstance(kCGColorSpaceGenericXYZ, unicode)
+        self.assertIsInstance(kCGColorSpaceACESCGLinear, unicode)
+        self.assertIsInstance(kCGColorSpaceITUR_709, unicode)
+        self.assertIsInstance(kCGColorSpaceITUR_2020, unicode)
+        self.assertIsInstance(kCGColorSpaceROMMRGB, unicode)
+        self.assertIsInstance(kCGColorSpaceDCIP3, unicode)
+
+    @min_os_level('10.12')
+    def testConstants10_12(self):
+        self.assertIsInstance(kCGColorSpaceExtendedSRGB, unicode)
+        self.assertIsInstance(kCGColorSpaceLinearSRGB, unicode)
+        self.assertIsInstance(kCGColorSpaceExtendedLinearSRGB, unicode)
+        self.assertIsInstance(kCGColorSpaceExtendedGray, unicode)
+        self.assertIsInstance(kCGColorSpaceLinearGray, unicode)
+        self.assertIsInstance(kCGColorSpaceExtendedLinearGray, unicode)
+
+    @min_os_level('10.13')
+    def testConstants10_13(self):
+        self.assertIsInstance(kCGColorSpaceGenericLab, unicode)
 
     def testFunctions(self):
         self.assertResultIsCFRetained(CGColorSpaceCreateDeviceGray)
@@ -159,6 +172,16 @@ class TestCGColorSpace (TestCase):
         v = CGColorSpaceCopyName(csp)
         self.assertIsInstance(v, unicode)
 
+    @min_os_level('10.12')
+    def testFunctions10_12(self):
+        self.assertResultIsCFRetained(CGColorSpaceCopyICCData)
+        self.assertResultHasType(CGColorSpaceIsWideGamutRGB, objc._C_BOOL)
+        self.assertResultHasType(CGColorSpaceSupportsOutput, objc._C_BOOL)
+        self.assertResultIsCFRetained(CGColorSpaceCreateWithICCData)
+
+    @min_os_level('10.13')
+    def testFunctions10_13(self):
+        CGColorSpaceGetName
 
 if __name__ == "__main__":
     main()
