@@ -3,11 +3,6 @@ from PyObjCTools.TestSupport import *
 from Quartz.CoreGraphics import *
 
 class TestCGPDFArray (TestCase):
-
-    @expectedFailure
-    def testIncomplete(self):
-        self.fail("Tests are too minimal")
-
     def testTypes(self):
         self.assertIsOpaquePointer(CGPDFArrayRef)
 
@@ -43,5 +38,9 @@ class TestCGPDFArray (TestCase):
 
         CGPDFArrayGetCount
 
+    @min_os_level('10.14')
+    def testFunctions10_14(self):
+        self.assertArgIsBlock(CGPDFArrayApplyBlock, 1, b'Bl^{CGPDFObject=}^v')
+
 if __name__ == "__main__":
     main()
