@@ -2,11 +2,6 @@
 from PyObjCTools.TestSupport import *
 from Quartz import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
 class TestCVOpenGLTextureCache (TestCase):
     def testTypes(self):
         self.assertIsCFType(CVOpenGLTextureCacheRef)
@@ -19,23 +14,17 @@ class TestCVOpenGLTextureCache (TestCase):
 
     @expectedFailure
     def testFunctions(self):
+        self.assertIsInstance(CVOpenGLTextureCacheGetTypeID, (int, long))
+        CVOpenGLTextureCacheRetain
+        CVOpenGLTextureCacheRelease
 
-        self.fail("Create CGLContext and CGLFormat")
         self.assertArgIsOut(CVOpenGLTextureCacheCreate, 5)
-        rv, cache = CVOpenGLTextureCacheCreate(None,  None, cglCtx, cglFmt, None, None)
-        self.assertEqual(rv, 0)
-        self.assertIsInstance(cache, CVOpenGLTextureCacheRef)
+        self.assertArgIsCFRetained(CVOpenGLTextureCacheCreate, 5)
 
-        v = CVOpenGLTextureCacheRetain(cache)
-        self.assertTrue(v is cache)
-        CVOpenGLTextureCacheRelease(v)
+        self.assertArgIsOut(CVOpenGLTextureCacheCreateTextureFromImage, 4)
+        self.assertArgIsCFRetained(CVOpenGLTextureCacheCreateTextureFromImage, 4)
 
-        self.fail("Create CVImageBufferRef")
-        rv, texture = CVOpenGLTextureCacheCreateTextureFromImage(None, cache, img, None, None)
-        self.assertEqual(rv, 0)
-        self.assertIsInstance(cache, CVOpenGLTextureRef)
-
-        CVOpenGLTextureCacheFlush(cache, 0)
+        CVOpenGLTextureCacheFlush
 
 if __name__ == "__main__":
     main()
