@@ -8,6 +8,7 @@ class TestCVReturn (TestCase):
         self.assertEqual(kCVReturnError, -6660)
         self.assertEqual(kCVReturnInvalidArgument, -6661)
         self.assertEqual(kCVReturnAllocationFailed, -6662)
+        self.assertEqual(kCVReturnUnsupported, -6663)
         self.assertEqual(kCVReturnInvalidDisplay, -6670)
         self.assertEqual(kCVReturnDisplayLinkAlreadyRunning, -6671)
         self.assertEqual(kCVReturnDisplayLinkNotRunning, -6672)
@@ -16,8 +17,12 @@ class TestCVReturn (TestCase):
         self.assertEqual(kCVReturnInvalidSize, -6681)
         self.assertEqual(kCVReturnInvalidPixelBufferAttributes, -6682)
         self.assertEqual(kCVReturnPixelBufferNotOpenGLCompatible, -6683)
+        self.assertEqual(kCVReturnPixelBufferNotMetalCompatible, -6684)
+        self.assertEqual(kCVReturnWouldExceedAllocationThreshold, -6689)
         self.assertEqual(kCVReturnPoolAllocationFailed, -6690)
         self.assertEqual(kCVReturnInvalidPoolAttributes, -6691)
+        self.assertEqual(kCVReturnRetry, -6692)
+        self.assertEqual(kCVReturnLast, -6699)
 
 if __name__ == "__main__":
     main()
