@@ -2,11 +2,6 @@
 from PyObjCTools.TestSupport import *
 from Quartz import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
 class TestQuartzFilterManager (TestCase):
     @min_os_level('10.5')
     def testMethods(self):
@@ -29,6 +24,9 @@ class TestQuartzFilterManager (TestCase):
         self.assertIsInstance(kQuartzFilterPDFWorkflowDomain, unicode)
         self.assertIsInstance(kQuartzFilterPrintingDomain, unicode)
 
+    @expectedFailure
+    def testGlobalUpdateOK(self):
+        self.fail("Not yet supported")
 
 if __name__ == "__main__":
     main()
